======================================
 Welcome to fabtools's documentation!
======================================

.. include:: ../README.rst


API Documentation
=================

.. toctree::
   :maxdepth: 1

   api/index
   api/require/index


History
=======

.. toctree::
   :maxdepth: 1

   CHANGELOG


Development
===========

.. toctree::
   :maxdepth: 1

   tests


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
